pub struct FriInstanceInfo<F: RichField + Extendable<D>, const D: usize> {
pub oracles: Vec<FriOracleInfo>,
pub batches: Vec<FriBatchInfo<F, D>>,
}Expand description
Describes an instance of a FRI-based batch opening.
Fields
oracles: Vec<FriOracleInfo>The oracles involved, not counting oracles created during the commit phase.
batches: Vec<FriBatchInfo<F, D>>Batches of openings, where each batch is associated with a particular point.