pub struct SimpleGeneratorAdapter<F: RichField + Extendable<D>, SG: SimpleGenerator<F, D> + ?Sized, const D: usize> { /* private fields */ }Trait Implementations
Sourceimpl<F: Debug + RichField + Extendable<D>, SG: Debug + SimpleGenerator<F, D> + ?Sized, const D: usize> Debug for SimpleGeneratorAdapter<F, SG, D>
impl<F: Debug + RichField + Extendable<D>, SG: Debug + SimpleGenerator<F, D> + ?Sized, const D: usize> Debug for SimpleGeneratorAdapter<F, SG, D>
Sourceimpl<F: RichField + Extendable<D>, SG: SimpleGenerator<F, D>, const D: usize> WitnessGenerator<F, D> for SimpleGeneratorAdapter<F, SG, D>
impl<F: RichField + Extendable<D>, SG: SimpleGenerator<F, D>, const D: usize> WitnessGenerator<F, D> for SimpleGeneratorAdapter<F, SG, D>
fn id(&self) -> String
Sourcefn watch_list(&self) -> Vec<Target>
fn watch_list(&self) -> Vec<Target>
Targets to be “watched” by this generator. Whenever a target in the watch list is populated,
the generator will be queued to run.
Sourcefn run(
&self,
witness: &PartitionWitness<'_, F>,
out_buffer: &mut GeneratedValues<F>,
) -> bool
fn run( &self, witness: &PartitionWitness<'_, F>, out_buffer: &mut GeneratedValues<F>, ) -> bool
Run this generator, returning a flag indicating whether the generator is finished. If the
flag is true, the generator will never be run again, otherwise it will be queued for another
run next time a target in its watch list is populated.
fn serialize( &self, dst: &mut Vec<u8>, common_data: &CommonCircuitData<F, D>, ) -> IoResult<()>
fn deserialize( src: &mut Buffer<'_>, common_data: &CommonCircuitData<F, D>, ) -> IoResult<Self>