../../.cargo/katex-header.html

ReducingFactor

Struct ReducingFactor 

pub struct ReducingFactor<F: Field> { /* private fields */ }
When verifying the composition polynomial in FRI we have to compute sums of the form (sum_0^k a^i * x_i)/d_0 + (sum_k^r a^i * y_i)/d_1 The most efficient way to do this is to compute both quotient separately using Horner’s method, scale the second one by a^(r-1-k), and add them up. This struct abstract away these operations by implementing Horner’s method and keeping track of the number of multiplications by a to compute the scaling factor. See https://github.com/0xPolygonZero/plonky2/pull/69 for more details and discussions.

Implementations

Source

impl<F: Field> ReducingFactor<F>

pub const fn new(base: F) -> Self

pub fn reduce( &mut self, iter: impl DoubleEndedIterator<Item = impl Borrow<F>>, ) -> F

pub fn reduce_ext<FE, P, const D: usize>( &mut self, iter: impl DoubleEndedIterator<Item = impl Borrow<P>>, ) -> P
where FE: FieldExtension<D, BaseField = F>, P: PackedField<Scalar = FE>,

pub fn reduce_polys( &mut self, polys: impl DoubleEndedIterator<Item = impl Borrow<PolynomialCoeffs<F>>>, ) -> PolynomialCoeffs<F>

pub fn reduce_polys_base<BF: Extendable<D, Extension = F>, const D: usize>( &mut self, polys: impl IntoIterator<Item = impl Borrow<PolynomialCoeffs<BF>>>, ) -> PolynomialCoeffs<F>

pub fn shift(&mut self, x: F) -> F

pub fn shift_poly(&mut self, p: &mut PolynomialCoeffs<F>)

pub fn reset(&mut self)